@@ -10,7 +10,7 @@
 %                            A   A    V    IIIII                              %
 %                                                                             %
 %                                                                             %
-%            Read Microsoft Audio/Visual Interleaved Image Format.            %
+%            Read Microsoft Audio/Visual Interleaved Image Format             %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
@@ -18,7 +18,7 @@
 %                                March  2004                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -44,7 +44,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
-#include "magick/color-private.h"
+#include "magick/cache.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
@@ -1574,11 +1574,6 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 (void) CloseBlob(image);
                 return(GetFirstImageInList(image));
               }
-            if (SetImageExtent(image,0,0) == MagickFalse)
-              {
-                InheritException(exception,&image->exception);
-                return(DestroyImageList(image));
-              }
             jpeg_pixels=(JSAMPLE *) AcquireQuantumMemory((size_t)
               image->columns,jpeg_info.output_components*sizeof(JSAMPLE));
             if (jpeg_pixels == (JSAMPLE *) NULL)
@@ -1591,10 +1586,10 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             {
               (void) jpeg_read_scanlines(&jpeg_info,scanline,1);
               p=jpeg_pixels;
-              q=SetImagePixels(image,0,y,image->columns,1);
+              q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
               if (q == (PixelPacket *) NULL)
                 break;
-              indexes=GetIndexes(image);
+              indexes=GetAuthenticIndexQueue(image);
               if (jpeg_info.data_precision > 8)
               {
                 if (jpeg_info.output_components == 1)
@@ -1644,7 +1639,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                         GETJSAMPLE(*p++));
                     q++;
                   }
-                  if (SyncImagePixels(image) == MagickFalse)
+                  if (SyncAuthenticPixels(image,exception) == MagickFalse)
                     break;
               if (image->previous == (Image *) NULL)
                 {
@@ -1670,10 +1665,10 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 */
                 for (y=0; y < (long) image->rows; y++)
                 {
-                  q=GetImagePixels(image,0,y,image->columns,1);
+                  q=GetAuthenticPixels(image,0,y,image->columns,1,exception);
                   if (q == (PixelPacket *) NULL)
                     break;
-                  indexes=GetIndexes(image);
+                  indexes=GetAuthenticIndexQueue(image);
                   for (x=0; x < (long) image->columns; x++)
                   {
                     q->red=(Quantum) (QuantumRange-q->red);
@@ -1682,7 +1677,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     indexes[x]=(IndexPacket) (QuantumRange-indexes[x]);
                     q++;
                   }
-                  if (SyncImagePixels(image) == MagickFalse)
+                  if (SyncAuthenticPixels(image,exception) == MagickFalse)
                     break;
                 }
               }
@@ -1715,11 +1710,6 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           */
           image->columns=avi_info.width;
           image->rows=avi_info.height;
-          if (SetImageExtent(image,0,0) == MagickFalse)
-            {
-              InheritException(exception,&image->exception);
-              return(DestroyImageList(image));
-            }
           image->depth=8;
           image->units=PixelsPerCentimeterResolution;
           image->x_resolution=(double) bmp_info.x_pixels/100.0;
@@ -1769,10 +1759,10 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               for (y=(long) image->rows-1; y >= 0; y--)
               {
                 p=pixels+(image->rows-y-1)*bytes_per_line;
-                q=SetImagePixels(image,0,y,image->columns,1);
+                q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
                 if (q == (PixelPacket *) NULL)
                   break;
-                indexes=GetIndexes(image);
+                indexes=GetAuthenticIndexQueue(image);
                 for (x=0; x < ((long) image->columns-7); x+=8)
                 {
                   for (bit=0; bit < 8; bit++)
@@ -1795,7 +1785,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   }
                   p++;
                 }
-                if (SyncImagePixels(image) == MagickFalse)
+                if (SyncAuthenticPixels(image,exception) == MagickFalse)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
@@ -1815,10 +1805,10 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               for (y=(long) image->rows-1; y >= 0; y--)
               {
                 p=pixels+(image->rows-y-1)*bytes_per_line;
-                q=SetImagePixels(image,0,y,image->columns,1);
+                q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
                 if (q == (PixelPacket *) NULL)
                   break;
-                indexes=GetIndexes(image);
+                indexes=GetAuthenticIndexQueue(image);
                 for (x=0; x < ((long) image->columns-1); x+=2)
                 {
                   index=ConstrainColormapIndex(image,((*p >> 4) & 0xf));
@@ -1836,7 +1826,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   *q++=image->colormap[(long) index];
                   p++;
                 }
-                if (SyncImagePixels(image) == MagickFalse)
+                if (SyncAuthenticPixels(image,exception) == MagickFalse)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
@@ -1857,10 +1847,10 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               for (y=(long) image->rows-1; y >= 0; y--)
               {
                 p=pixels+(image->rows-y-1)*bytes_per_line;
-                q=SetImagePixels(image,0,y,image->columns,1);
+                q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
                 if (q == (PixelPacket *) NULL)
                   break;
-                indexes=GetIndexes(image);
+                indexes=GetAuthenticIndexQueue(image);
                 for (x=0; x < (long) image->columns; x++)
                 {
                   index=ConstrainColormapIndex(image,*p);
@@ -1869,7 +1859,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   p++;
                   q++;
                 }
-                if (SyncImagePixels(image) == MagickFalse)
+                if (SyncAuthenticPixels(image,exception) == MagickFalse)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
@@ -1894,7 +1884,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               for (y=(long) image->rows-1; y >= 0; y--)
               {
                 p=pixels+(image->rows-y-1)*bytes_per_line;
-                q=SetImagePixels(image,0,y,image->columns,1);
+                q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
                 if (q == (PixelPacket *) NULL)
                   break;
                 for (x=0; x < (long) image->columns; x++)
@@ -1908,7 +1898,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   q->blue=ScaleCharToQuantum(ScaleColor5to8(word & 0x1f));
                   q++;
                 }
-                if (SyncImagePixels(image) == MagickFalse)
+                if (SyncAuthenticPixels(image,exception) == MagickFalse)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
@@ -1930,7 +1920,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               for (y=(long) image->rows-1; y >= 0; y--)
               {
                 p=pixels+(image->rows-y-1)*bytes_per_line;
-                q=SetImagePixels(image,0,y,image->columns,1);
+                q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
                 if (q == (PixelPacket *) NULL)
                   break;
                 for (x=0; x < (long) image->columns; x++)
@@ -1942,7 +1932,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     q->opacity=ScaleCharToQuantum(*p++);
                   q++;
                 }
-                if (SyncImagePixels(image) == MagickFalse)
+                if (SyncAuthenticPixels(image,exception) == MagickFalse)
                   break;
                 offset=(MagickOffsetType) image->rows-y-1;
                 if (image->previous == (Image *) NULL)
