@@ -160,11 +160,11 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    length=(size_t) image->columns;
-    pixels=(unsigned char *) AcquireQuantumMemory(length,4*sizeof(*pixels));
+    pixels=(unsigned char *) AcquireQuantumMemory(image->columns,
+      4*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL) 
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    length*=4*sizeof(*pixels);
+    length=(size_t) 4*image->columns;
     for (y=0; y < (long) image->rows; y++)
     {
       count=ReadBlob(image,length,pixels);
@@ -329,6 +329,9 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
   register unsigned char
     *q;
 
+  ssize_t
+    count;
+
   unsigned char
     *pixels;
 
@@ -357,7 +360,7 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
     /*
       Allocate memory for pixels.
     */
-    pixels=(unsigned char *) AcquireMagickMemory((size_t) image->columns*
+    pixels=(unsigned char *) AcquireQuantumMemory((size_t) image->columns,
       4*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
@@ -379,7 +382,9 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
         *q++=ScaleQuantumToChar(p->blue);
         p++;
       }
-      (void) WriteBlob(image,(size_t) (q-pixels),pixels);
+      count=WriteBlob(image,(size_t) (q-pixels),pixels);
+      if (count != (ssize_t) (q-pixels))
+        break;
       if ((image->previous == (Image *) NULL) &&
           (SetImageProgress(image,SaveImageTag,y,image->rows) == MagickFalse))
         break;
