@@ -17,7 +17,7 @@
 %                               February 2002                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -201,11 +201,15 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   */
   (void) CloneString(&draw_info->text,caption);
   status=GetMultilineTypeMetrics(image,draw_info,&metrics);
-  (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
-    -metrics.bounds.x1+draw_info->stroke_width/2.0,metrics.ascent+
-    draw_info->stroke_width/2.0);
-  if (draw_info->gravity == UndefinedGravity)
-    (void) CloneString(&draw_info->geometry,geometry);
+  if (draw_info->gravity != UndefinedGravity)
+    image->page.x=(long) (metrics.bounds.x1-draw_info->stroke_width/2.0);
+  else
+    {
+      (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
+        -metrics.bounds.x1+draw_info->stroke_width/2.0,metrics.ascent+
+        draw_info->stroke_width/2.0);
+      (void) CloneString(&draw_info->geometry,geometry);
+    }
   (void) AnnotateImage(image,draw_info);
   draw_info=DestroyDrawInfo(draw_info);
   caption=DestroyString(caption);
@@ -243,7 +247,7 @@ ModuleExport unsigned long RegisterCAPTIONImage(void)
   entry=SetMagickInfo("CAPTION");
   entry->decoder=(DecodeImageHandler *) ReadCAPTIONImage;
   entry->adjoin=MagickFalse;
-  entry->format_type=ImplicitFormatType;
+  entry->format_type=ExplicitFormatType;
   entry->description=ConstantString("Image caption");
   entry->module=ConstantString("CAPTION");
   (void) RegisterMagickInfo(entry);
