@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/constitute.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -49,6 +50,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -91,8 +93,6 @@ static MagickBooleanType IsDJVU(const unsigned char *magick,const size_t length)
     return(MagickTrue);
   return(MagickFalse);
 }
-
-
 
 #if defined(MAGICKCORE_DJVU_DELEGATE)
 /*
@@ -211,7 +211,7 @@ message_tag_name(ddjvu_message_tag_t tag)
 /* write out nice info on the message,
  * and store in *user* data the info on progress.
  * */
-void
+int
 process_message(ddjvu_message_t *message)
 {
 
@@ -220,7 +220,7 @@ process_message(ddjvu_message_t *message)
 #endif
 
    if (! message)
-      return;
+      return(-1);
 #if DEBUG
    printf("*** %s: %s.\n",__FUNCTION__, message_tag_name(message->m_any.tag));
 #endif
@@ -304,6 +304,7 @@ process_message(ddjvu_message_t *message)
    default:
       printf("unexpected\n");
    };
+  return(message->m_any.tag);
 }
 
 
@@ -380,10 +381,10 @@ get_page_image(LoadContext *lc, ddjvu_page_t *page, int x, int y, int w, int h,
 
                 for (y=0; y < (long) image->rows; y++)
                         {
-                                PixelPacket * o = SetImagePixels(image,0,y,image->columns,1);
+                                PixelPacket * o = QueueAuthenticPixels(image,0,y,image->columns,1,&image->exception);
                                 if (o == (PixelPacket *) NULL)
                                         break;
-                                indexes=GetIndexes(image);
+                                indexes=GetAuthenticIndexQueue(image);
                                 bit=0;
                                 byte=0;
 
@@ -398,7 +399,7 @@ get_page_image(LoadContext *lc, ddjvu_page_t *page, int x, int y, int w, int h,
                                                         bit=0;
                                                 byte>>=1;
                                         }
-                                if (SyncImagePixels(image) == MagickFalse)
+                                if (SyncAuthenticPixels(image,&image->exception) == MagickFalse)
                                         break;
                         }
                 SyncImage(image);
@@ -420,61 +421,23 @@ get_page_image(LoadContext *lc, ddjvu_page_t *page, int x, int y, int w, int h,
 #if DEBUG
                                if (i % 1000 == 0) printf("%d\n",i);
 #endif
-                               r = SetImagePixels(lc->image,0,i,lc->image->columns,1);
+                               r = QueueAuthenticPixels(lc->image,0,i,lc->image->columns,1,&image->exception);
 
                                 ImportQuantumPixels(lc->image,
+                                                    (ViewInfo *) NULL,
                                                     quantum_info,
                                                     RGBQuantum, /*GrayQuantum*/
-                                                    q+i*stride);
-                                SyncImagePixels(lc->image);
+                                                    q+i*stride,&image->exception);
+                                SyncAuthenticPixels(lc->image,&image->exception);
                         }
         }
 }
 
 
-static int
-get_page_line(PixelPacket *q, LoadContext *lc, int row)
-{
-
-        ddjvu_rect_t rect, pagerect;
-        rect.x = 0;
-        rect.y = row;
-        rect.h = 1;             /* /10 */
-
-        pagerect.x = 0;
-        pagerect.y = 0;
-        pagerect.w = lc->image->columns;
-        pagerect.h = lc->image->rows;
-
-
-        ddjvu_format_t *format = ddjvu_format_create(
-#if RGB
-                DDJVU_FORMAT_RGB24
-#else
-                DDJVU_FORMAT_GREY8
-#endif
-                ,
-                0, NULL);
-        ddjvu_format_set_row_order(format, 0);
-        ddjvu_format_set_y_direction(format, 1);
-
-        int ret = ddjvu_page_render(lc->page,
-                                    DDJVU_RENDER_COLOR, /* ddjvu_render_mode_t */
-                                    &pagerect,
-                                    &rect,     /* mmc: ?? */
-                                    format,
-                                    pagerect.w
-#if RGB
-                                    * 3
-#endif
-                                    , /* ?? */
-                                    (char*)q);
-        ddjvu_format_release(format);
-        return ret;
-}
+#if defined(MAGICKCORE_DJVU_DELEGATE)
 
 static int
-get_page_line_new(LoadContext *lc, int row, QuantumInfo* quantum_info)
+get_page_line(LoadContext *lc, int row, QuantumInfo* quantum_info)
 {
 
         ddjvu_rect_t rect, pagerect;
@@ -515,17 +478,19 @@ get_page_line_new(LoadContext *lc, int row, QuantumInfo* quantum_info)
                                     (char*)q);
 
         ImportQuantumPixels(lc->image,
+                            (ViewInfo *) NULL,
                             quantum_info,
 #if RGB
                             RGBQuantum
 #else
                             GrayQuantum
 #endif
-                            ,q);
+                            ,q,&lc->image->exception);
         free(q);
         ddjvu_format_release(format);
         return ret;
 }
+#endif
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -557,16 +522,21 @@ get_page_line_new(LoadContext *lc, int row, QuantumInfo* quantum_info)
 %    o exception: return any errors or warnings in this structure.
 %
 */
-static Image*
-ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info, ExceptionInfo *exception)
+
+static Image *ReadOneDJVUImage(LoadContext* lc,const int pagenum,
+  const ImageInfo *image_info,ExceptionInfo *exception)
 {
         /* so, we know that the page is there! Get its dimension, and  */
 
         /* Read one DJVU image */
         Image *image = lc->image;
         int logging;
+        int tag;
+
         /* register PixelPacket *q; */
 
+        ddjvu_pageinfo_t info;
+        ddjvu_pageinfo_t rect;
         QuantumInfo *quantum_info;
 
         ddjvu_message_t *message;
@@ -578,10 +548,12 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
         lc->page = ddjvu_page_create_by_pageno(lc->document, pagenum); /*  0? */
 
         /* pump data untill the page is ready for rendering. */
+        tag=(-1);
         do {
                 while ((message = ddjvu_message_peek(lc->context)))
                         {
-                                process_message(message);
+                                tag=process_message(message);
+                                if (tag == 0) break;
                                 ddjvu_message_pop(lc->context);
                         }
                 /* fixme: maybe exit? */
@@ -590,14 +562,36 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
                 message = pump_data_until_message(lc,image);
                 if (message)
                         do {
-                                process_message(message);
+                                tag=process_message(message);
+                                if (tag == 0) break;
                                 ddjvu_message_pop(lc->context);
                         } while ((message = ddjvu_message_peek(lc->context)));
         } while (!ddjvu_page_decoding_done(lc->page));
 
-        ddjvu_pageinfo_t info;
         ddjvu_document_get_pageinfo(lc->document, pagenum, &info);
 
+        image->x_resolution = (float) info.dpi;
+        image->y_resolution =(float) info.dpi;
+        if (image_info->density != (char *) NULL)
+          {
+            int
+              flags;
+
+            GeometryInfo
+              geometry_info;
+
+            /*
+              Set rendering resolution.
+            */
+            flags=ParseGeometry(image_info->density,&geometry_info);
+            image->x_resolution=geometry_info.rho;
+            image->y_resolution=geometry_info.sigma;
+            if ((flags & SigmaValue) == 0)
+              image->y_resolution=image->x_resolution;
+            info.width*=image->x_resolution/info.dpi;
+            info.height*=image->y_resolution/info.dpi;
+            info.dpi=(long) fmax(image->x_resolution,image->y_resolution);
+          }
         ddjvu_page_type_t type = ddjvu_page_get_type(lc->page);
 
         /* double -> float! */
@@ -608,9 +602,6 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
 
         SetImageExtent(image,info.width,info.height);
 
-        image->x_resolution = (float) info.dpi;
-        image->y_resolution =(float) info.dpi;
-
         /* mmc: bitonal should be palettized, and compressed! */
         if (type == DDJVU_PAGETYPE_BITONAL){
                 image->colorspace = GRAYColorspace;
@@ -636,23 +627,19 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
 
 #if 1                           /* per_line */
         quantum_info=AcquireQuantumInfo(image_info,image);
+        if (quantum_info == (QuantumInfo *) NULL)
+          ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
 
-        /* q = SetImagePixels(image,0,0,image->columns,image->rows); */
+        /* q = QueueAuthenticPixels(image,0,0,image->columns,image->rows); */
         get_page_image(lc, lc->page, 0, 0, info.width, info.height, quantum_info);
 #else
         int i;
         for (i = 0;i< image->rows; i++)
                 {
                         printf("%d\n",i);
-#if 0
-                        q = SetImagePixels(image,0,i,image->columns,1);
-                        get_page_line(q,lc, i);
-                        SyncImagePixels(image);
-#else
-                        q = SetImagePixels(image,0,i,image->columns,1);
-                        get_page_line_new(lc, i, quantum_info);
-                        SyncImagePixels(image);
-#endif
+                        q = QueueAuthenticPixels(image,0,i,image->columns,1);
+                        get_page_line(lc, i, quantum_info);
+                        SyncAuthenticPixels(image);
                 }
 
 #endif /* per_line */
@@ -664,7 +651,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
 
         SyncImage(image);
         quantum_info=DestroyQuantumInfo(quantum_info);
-        /* indexes=GetIndexes(image); */
+        /* indexes=GetAuthenticIndexQueue(image); */
         /* mmc: ??? Convert PNM pixels to runlength-encoded MIFF packets. */
         /* image->colors =  */
 
@@ -676,12 +663,12 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
         }
 
         /* image->page.y=mng_info->y_off[mng_info->object_id]; */
+        if (tag == 0)
+          image=DestroyImage(image);
         return image;
         /* end of reading one DJVU page/image */
 }
 
-
-
 #if 0
 /* palette */
   if (AcquireImageColormap(image,2) == MagickFalse)
@@ -697,10 +684,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
   image->colormap[1].blue=0;
 #endif
 
-
-
-static void
-djvu_close_lc(LoadContext* lc)
+static void djvu_close_lc(LoadContext* lc)
 {
         if (lc->document)
                 ddjvu_document_release(lc->document);
@@ -711,7 +695,6 @@ djvu_close_lc(LoadContext* lc)
         RelinquishMagickMemory(lc);
 }
 
-
 static Image *ReadDJVUImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
 {
@@ -828,15 +811,23 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,
   }
 
   images=NewImageList();
-  for (i=0; i < (long) lc->pages; i++)
+  i=0;
+  if (image_info->number_scenes != 0)
+    i=image_info->scene;
+  for ( ; i < (long) lc->pages; i++)
   {
     image=ReadOneDJVUImage(lc,i,image_info,exception);
+    if (image == (Image *) NULL)
+      break;
     AppendImageToList(&images,CloneImageList(image,exception));
+    if (image_info->number_scenes != 0)
+      if (image->scene >= (image_info->scene+image_info->number_scenes-1))
+        break;
   }
-
   djvu_close_lc(lc);
-  (void) CloseBlob(image);
-  image=DestroyImageList(image);
+  (void) CloseBlob(images);
+  if (image != (Image *) NULL)
+    image=DestroyImageList(image);
 
 #if 0
   if ((image->page.width == 0) && (image->page.height == 0))
