@@ -10,14 +10,14 @@
 %                        IIIII   CCCC   OOO   N   N                           %
 %                                                                             %
 %                                                                             %
-%                   Read Microsoft Windows Icon Format.                       %
+%                   Read Microsoft Windows Icon Format                        %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -336,11 +337,6 @@ static Image *ReadICONImage(const ImageInfo *image_info,
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    if (SetImageExtent(image,0,0) == MagickFalse)
-      {
-        InheritException(exception,&image->exception);
-        return(DestroyImageList(image));
-      }
     bytes_per_line=(((image->columns*icon_info.bits_per_pixel)+31) & ~31) >> 3;
     scanline_pad=((((image->columns*icon_info.bits_per_pixel)+31) & ~31)-
       (image->columns*icon_info.bits_per_pixel)) >> 3;
@@ -353,10 +349,10 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         */
         for (y=(long) image->rows-1; y >= 0; y--)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
+          q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
-          indexes=GetIndexes(image);
+          indexes=GetAuthenticIndexQueue(image);
           for (x=0; x < (long) (image->columns-7); x+=8)
           {
             byte=(unsigned long) ReadBlobByte(image);
@@ -373,7 +369,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
             }
           for (x=0; x < (long) scanline_pad; x++)
             (void) ReadBlobByte(image);
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
             {
@@ -392,10 +388,10 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         */
         for (y=(long) image->rows-1; y >= 0; y--)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
+          q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
-          indexes=GetIndexes(image);
+          indexes=GetAuthenticIndexQueue(image);
           for (x=0; x < ((long) image->columns-1); x+=2)
           {
             byte=(unsigned long) ReadBlobByte(image);
@@ -409,7 +405,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
             }
           for (x=0; x < (long) scanline_pad; x++)
             (void) ReadBlobByte(image);
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
             {
@@ -428,10 +424,10 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         */
         for (y=(long) image->rows-1; y >= 0; y--)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
+          q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
-          indexes=GetIndexes(image);
+          indexes=GetAuthenticIndexQueue(image);
           for (x=0; x < (long) image->columns; x++)
           {
             byte=(unsigned long) ReadBlobByte(image);
@@ -439,7 +435,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
           }
           for (x=0; x < (long) scanline_pad; x++)
             (void) ReadBlobByte(image);
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
             {
@@ -458,10 +454,10 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         */
         for (y=(long) image->rows-1; y >= 0; y--)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
+          q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
-          indexes=GetIndexes(image);
+          indexes=GetAuthenticIndexQueue(image);
           for (x=0; x < (long) image->columns; x++)
           {
             byte=(unsigned long) ReadBlobByte(image);
@@ -470,7 +466,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
           }
           for (x=0; x < (long) scanline_pad; x++)
             (void) ReadBlobByte(image);
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
             {
@@ -490,7 +486,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         */
         for (y=(long) image->rows-1; y >= 0; y--)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
+          q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
           for (x=0; x < (long) image->columns; x++)
@@ -499,14 +495,14 @@ static Image *ReadICONImage(const ImageInfo *image_info,
             q->green=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
             q->red=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
             if (icon_info.bits_per_pixel == 32)
-              q->opacity=(Quantum) QuantumRange-ScaleCharToQuantum(
-                (unsigned char) ReadBlobByte(image));
+              q->opacity=(Quantum) (QuantumRange-ScaleCharToQuantum(
+                (unsigned char) ReadBlobByte(image)));
             q++;
           }
           if (icon_info.bits_per_pixel == 24)
             for (x=0; x < (long) scanline_pad; x++)
               (void) ReadBlobByte(image);
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
             {
@@ -530,7 +526,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         image->storage_class=DirectClass;
         for (y=(long) image->rows-1; y >= 0; y--)
         {
-          q=GetImagePixels(image,0,y,image->columns,1);
+          q=GetAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
           for (x=0; x < ((long) image->columns-7); x+=8)
@@ -550,7 +546,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
          if ((image->columns % 32)  != 0)
            for (x=0; x < (long) ((32-(image->columns % 32))/8); x++)
              (void) ReadBlobByte(image);
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
         }
       }
@@ -718,12 +714,12 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
     offset,
     scene;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     i,
     x;
@@ -884,10 +880,10 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
         */
         for (y=0; y < (long) next->rows; y++)
         {
-          p=AcquireImagePixels(next,0,y,next->columns,1,&next->exception);
+          p=GetVirtualPixels(next,0,y,next->columns,1,&next->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          indexes=GetIndexes(next);
+          indexes=GetVirtualIndexQueue(next);
           q=pixels+(next->rows-y-1)*bytes_per_line;
           bit=0;
           byte=0;
@@ -925,10 +921,10 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
         */
         for (y=0; y < (long) next->rows; y++)
         {
-          p=AcquireImagePixels(next,0,y,next->columns,1,&next->exception);
+          p=GetVirtualPixels(next,0,y,next->columns,1,&next->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          indexes=GetIndexes(next);
+          indexes=GetVirtualIndexQueue(next);
           q=pixels+(next->rows-y-1)*bytes_per_line;
           nibble=0;
           byte=0;
@@ -962,10 +958,10 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
         */
         for (y=0; y < (long) next->rows; y++)
         {
-          p=AcquireImagePixels(next,0,y,next->columns,1,&next->exception);
+          p=GetVirtualPixels(next,0,y,next->columns,1,&next->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          indexes=GetIndexes(next);
+          indexes=GetVirtualIndexQueue(next);
           q=pixels+(next->rows-y-1)*bytes_per_line;
           for (x=0; x < (long) next->columns; x++)
             *q++=(unsigned char) indexes[x];
@@ -986,7 +982,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
         */
         for (y=0; y < (long) next->rows; y++)
         {
-          p=AcquireImagePixels(next,0,y,next->columns,1,&next->exception);
+          p=GetVirtualPixels(next,0,y,next->columns,1,&next->exception);
           if (p == (const PixelPacket *) NULL)
             break;
           q=pixels+(next->rows-y-1)*bytes_per_line;
@@ -996,9 +992,9 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
             *q++=ScaleQuantumToChar(p->green);
             *q++=ScaleQuantumToChar(p->red);
             if (next->matte == MagickFalse)
-              *q++=ScaleQuantumToChar(255);
+              *q++=ScaleQuantumToChar(QuantumRange);
             else
-              *q++=ScaleQuantumToChar(p->opacity);
+              *q++=ScaleQuantumToChar(QuantumRange-p->opacity);
             p++;
           }
           if (icon_info.bits_per_pixel == 24)
@@ -1075,7 +1071,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
     scanline_pad=(((next->columns+31) & ~31)-next->columns) >> 3;
     for (y=((long) next->rows - 1); y >= 0; y--)
     {
-      p=AcquireImagePixels(next,0,y,next->columns,1,&next->exception);
+      p=GetVirtualPixels(next,0,y,next->columns,1,&next->exception);
       if (p == (const PixelPacket *) NULL)
         break;
       bit=0;
