@@ -10,14 +10,14 @@
 %                         M   M   OOO   N   N   OOO                           %
 %                                                                             %
 %                                                                             %
-%                   Read/Write Raw Bi-Level Bitmap Format.                    %
+%                   Read/Write Raw Bi-Level Bitmap Format                     %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
@@ -159,17 +160,12 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
   /*
     Convert bi-level image to pixel packets.
   */
-  if (SetImageExtent(image,0,0) == MagickFalse)
-    {
-      InheritException(exception,&image->exception);
-      return(DestroyImageList(image));
-    }
   for (y=0; y < (long) image->rows; y++)
   {
-    q=SetImagePixels(image,0,y,image->columns,1);
+    q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
     if (q == (PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=GetAuthenticIndexQueue(image);
     bit=0;
     byte=0;
     for (x=0; x < (long) image->columns; x++)
@@ -185,7 +181,7 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
         bit=0;
       byte>>=1;
     }
-    if (SyncImagePixels(image) == MagickFalse)
+    if (SyncAuthenticPixels(image,exception) == MagickFalse)
       break;
     status=SetImageProgress(image,LoadImageTag,y,image->rows);
     if (status == MagickFalse)
@@ -297,7 +293,7 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
   MagickBooleanType
     status;
 
-  register IndexPacket
+  register const IndexPacket
     *indexes;
 
   register const PixelPacket
@@ -330,10 +326,10 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
   (void) SetImageType(image,BilevelType);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=GetVirtualIndexQueue(image);
     bit=0;
     byte=0;
     for (x=0; x < (long) image->columns; x++)
