@@ -10,14 +10,14 @@
 %                            M   M  P       CCCC                              %
 %                                                                             %
 %                                                                             %
-%              Read/Write Magick Persistant Cache Image Format.               %
+%              Read/Write Magick Persistant Cache Image Format                %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -277,7 +277,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (c == (int) '=')
                 break;
-              if ((size_t) (p-keyword) < MaxTextExtent)
+              if ((size_t) (p-keyword) < (MaxTextExtent-1))
                 *p++=(char) c;
               c=ReadBlobByte(image);
             } while (c != EOF);
@@ -832,7 +832,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Attach persistent pixel cache.
     */
-    status=PersistCache(image,cache_filename,MagickTrue,&offset,exception);
+    status=PersistPixelCache(image,cache_filename,MagickTrue,&offset,exception);
     if (status == MagickFalse)
       ThrowReaderException(CacheError,"UnableToPersistPixelCache");
     /*
@@ -1315,7 +1315,7 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
     /*
       Initialize persistent pixel cache.
     */
-    status=PersistCache(image,cache_filename,MagickFalse,&offset,
+    status=PersistPixelCache(image,cache_filename,MagickFalse,&offset,
       &image->exception);
     if (status == MagickFalse)
       ThrowWriterException(CacheError,"UnableToPersistPixelCache");
