@@ -10,14 +10,14 @@
 %                            P       CCCC  DDDD                               %
 %                                                                             %
 %                                                                             %
-%                     Read/Write Photo CD Image Format.                       %
+%                     Read/Write Photo CD Image Format                        %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -43,6 +43,7 @@
 #include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/client.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
@@ -601,11 +602,6 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Allocate lumand chroma memory.
   */
-  if (SetImageExtent(image,0,0) == MagickFalse)
-    {
-      InheritException(exception,&image->exception);
-      return(DestroyImageList(image));
-    }
   number_pixels=(MagickSizeType) image->columns*image->rows;
   if (number_pixels != (size_t) number_pixels)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -682,7 +678,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         c2=chroma2;
         for (y=0; y < (long) image->rows; y++)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
+          q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
           for (x=0; x < (long) image->columns; x++)
@@ -692,7 +688,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             q->blue=ScaleCharToQuantum(*c2++);
             q++;
           }
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
         }
         image->colorspace=YCCColorspace;
@@ -790,7 +786,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   c2=chroma2;
   for (y=0; y < (long) image->rows; y++)
   {
-    q=SetImagePixels(image,0,y,image->columns,1);
+    q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
     if (q == (PixelPacket *) NULL)
       break;
     for (x=0; x < (long) image->columns; x++)
@@ -800,7 +796,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       q->blue=ScaleCharToQuantum(*c2++);
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
+    if (SyncAuthenticPixels(image,exception) == MagickFalse)
       break;
     if (image->previous == (Image *) NULL)
       {
@@ -936,8 +932,7 @@ ModuleExport void UnregisterPCDImage(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  WritePCDImage() writes an image in the Photo CD encoded image
-%  format.
+%  WritePCDImage() writes an image in the Photo CD encoded image format.
 %
 %  The format of the WritePCDImage method is:
 %
@@ -949,7 +944,6 @@ ModuleExport void UnregisterPCDImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 
 static MagickBooleanType WritePCDTile(Image *image,const char *page_geometry,
@@ -1033,7 +1027,7 @@ static MagickBooleanType WritePCDTile(Image *image,const char *page_geometry,
   */
   for (y=0; y < (long) tile_image->rows; y+=2)
   {
-    p=AcquireImagePixels(tile_image,0,y,tile_image->columns,2,
+    p=GetVirtualPixels(tile_image,0,y,tile_image->columns,2,
       &tile_image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
@@ -1042,7 +1036,7 @@ static MagickBooleanType WritePCDTile(Image *image,const char *page_geometry,
       (void) WriteBlobByte(image,ScaleQuantumToChar(p->red));
       p++;
     }
-    q=AcquireImagePixels(downsample_image,0,y >> 1,downsample_image->columns,
+    q=GetVirtualPixels(downsample_image,0,y >> 1,downsample_image->columns,
       1,&downsample_image->exception);
     if (q == (const PixelPacket *) NULL)
       break;
@@ -1051,7 +1045,7 @@ static MagickBooleanType WritePCDTile(Image *image,const char *page_geometry,
       (void) WriteBlobByte(image,ScaleQuantumToChar(q->green));
       q++;
     }
-    q=AcquireImagePixels(downsample_image,0,y >> 1,downsample_image->columns,
+    q=GetVirtualPixels(downsample_image,0,y >> 1,downsample_image->columns,
       1,&downsample_image->exception);
     if (q == (const PixelPacket *) NULL)
       break;
