@@ -10,14 +10,14 @@
 %                        P      IIIII   CCCC    T                             %
 %                                                                             %
 %                                                                             %
-%               Read/Write Apple Macintosh QuickDraw/PICT Format.             %
+%               Read/Write Apple Macintosh QuickDraw/PICT Format              %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/composite.h"
@@ -896,11 +897,6 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   image->x_resolution=DefaultResolution;
   image->y_resolution=DefaultResolution;
   image->units=UndefinedResolution;
-  if (SetImageExtent(image,0,0) == MagickFalse)
-    {
-      InheritException(exception,&image->exception);
-      return(DestroyImageList(image));
-    }
   /*
     Interpret PICT opcodes.
   */
@@ -1176,10 +1172,10 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             {
               if (p > (pixels+extent+image->columns))
                 ThrowReaderException(CorruptImageError,"NotEnoughPixelData");
-              q=SetImagePixels(tile_image,0,y,tile_image->columns,1);
+              q=QueueAuthenticPixels(tile_image,0,y,tile_image->columns,1,exception);
               if (q == (PixelPacket *) NULL)
                 break;
-              indexes=GetIndexes(tile_image);
+              indexes=GetAuthenticIndexQueue(tile_image);
               for (x=0; x < (long) tile_image->columns; x++)
               {
                 if (tile_image->storage_class == PseudoClass)
@@ -1232,7 +1228,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 p++;
                 q++;
               }
-              if (SyncImagePixels(tile_image) == MagickFalse)
+              if (SyncAuthenticPixels(tile_image,exception) == MagickFalse)
                 break;
               if ((tile_image->storage_class == DirectClass) &&
                   (pixmap.bits_per_pixel != 16))
@@ -1565,12 +1561,12 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
     size_rectangle,
     source_rectangle;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     i,
     x;
@@ -1881,10 +1877,10 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   if ((storage_class == PseudoClass) && (image->matte == MagickFalse))
     for (y=0; y < (long) image->rows; y++)
     {
-      p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+      p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
       if (p == (const PixelPacket *) NULL)
         break;
-      indexes=GetIndexes(image);
+      indexes=GetVirtualIndexQueue(image);
       for (x=0; x < (long) image->columns; x++)
         scanline[x]=(unsigned char) indexes[x];
       count+=EncodeImage(image,scanline,(unsigned long) (row_bytes & 0x7FFF),
@@ -1920,7 +1916,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
         opacity=scanline+3*image->columns;
         for (y=0; y < (long) image->rows; y++)
         {
-          p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+          p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
           red=scanline;
