@@ -520,7 +520,8 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
     }
     case JPEGCompression:
     {
-      status=InjectImageBlob(image_info,mask_image,"jpeg");
+      status=InjectImageBlob(image_info,image,mask_image,"jpeg",
+        &image->exception);
       break;
     }
     case LZWCompression:
@@ -1262,7 +1263,8 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
           Image data.
         */
         if (compression == JPEGCompression)
-          status=InjectImageBlob(image_info,image,"jpeg");
+          status=InjectImageBlob(image_info,image,image,"jpeg",
+            &image->exception);
         else
           if ((compression == FaxCompression) ||
               (compression == Group4Compression))
@@ -1352,7 +1354,8 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
             Image data.
           */
           if (compression == JPEGCompression)
-            status=InjectImageBlob(image_info,image,"jpeg");
+            status=InjectImageBlob(image_info,image,image,"jpeg",
+              &image->exception);
           else
             {
               /*
@@ -1486,7 +1489,8 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
               }
               case JPEGCompression:
               {
-                status=InjectImageBlob(image_info,image,"jpeg");
+                status=InjectImageBlob(image_info,image,image,"jpeg",
+                  &image->exception);
                 break;
               }
               case RLECompression:
