@@ -10,14 +10,14 @@
 %                            X   X   W W   DDDD                               %
 %                                                                             %
 %                                                                             %
-%                Read/Write X Windows System Window Dump Format.              %
+%                Read/Write X Windows System Window Dump Format               %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/cache.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
@@ -247,7 +248,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   comment[length]='\0';
   (void) SetImageProperty(image,"comment",comment);
   comment=DestroyString(comment);
-  if (count == 0)
+  if (count != (ssize_t) length)
     ThrowReaderException(CorruptImageError,"UnexpectedEndOfFile");
   /*
     Initialize the X image.
@@ -347,11 +348,6 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->storage_class=DirectClass;
   else
     image->storage_class=PseudoClass;
-  if (SetImageExtent(image,0,0) == MagickFalse)
-    {
-      InheritException(exception,&image->exception);
-      return(DestroyImageList(image));
-    }
   image->colors=header.ncolors;
   if (image_info->ping == MagickFalse)
     switch (image->storage_class)
@@ -400,7 +396,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (image->colors != 0)
           for (y=0; y < (long) image->rows; y++)
           {
-            q=SetImagePixels(image,0,y,image->columns,1);
+            q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
             if (q == (PixelPacket *) NULL)
               break;
             for (x=0; x < (long) image->columns; x++)
@@ -414,7 +410,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
               q->blue=ScaleShortToQuantum(colors[(long) index].blue);
               q++;
             }
-            if (SyncImagePixels(image) == MagickFalse)
+            if (SyncAuthenticPixels(image,exception) == MagickFalse)
               break;
             status=SetImageProgress(image,LoadImageTag,y,image->rows);
             if (status == MagickFalse)
@@ -423,7 +419,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         else
           for (y=0; y < (long) image->rows; y++)
           {
-            q=SetImagePixels(image,0,y,image->columns,1);
+            q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
             if (q == (PixelPacket *) NULL)
               break;
             for (x=0; x < (long) image->columns; x++)
@@ -440,7 +436,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
               q->blue=ScaleShortToQuantum((unsigned short) color);
               q++;
             }
-            if (SyncImagePixels(image) == MagickFalse)
+            if (SyncAuthenticPixels(image,exception) == MagickFalse)
               break;
             status=SetImageProgress(image,LoadImageTag,y,image->rows);
             if (status == MagickFalse)
@@ -463,10 +459,10 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
         for (y=0; y < (long) image->rows; y++)
         {
-          q=SetImagePixels(image,0,y,image->columns,1);
+          q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
             break;
-          indexes=GetIndexes(image);
+          indexes=GetAuthenticIndexQueue(image);
           for (x=0; x < (long) image->columns; x++)
           {
             index=ConstrainColormapIndex(image,XGetPixel(ximage,(int) x,
@@ -474,7 +470,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             indexes[x]=index;
             *q++=image->colormap[(long) index];
           }
-          if (SyncImagePixels(image) == MagickFalse)
+          if (SyncAuthenticPixels(image,exception) == MagickFalse)
             break;
           status=SetImageProgress(image,LoadImageTag,y,image->rows);
           if (status == MagickFalse)
@@ -600,12 +596,12 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
   MagickBooleanType
     status;
 
+  register const IndexPacket
+    *indexes;
+
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
   register long
     x;
 
@@ -753,13 +749,13 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
   scanline_pad=(bytes_per_line-((image->columns*bits_per_pixel) >> 3));
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    p=GetVirtualPixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
     q=pixels;
     if (image->storage_class == PseudoClass)
       {
-        indexes=GetIndexes(image);
+        indexes=GetVirtualIndexQueue(image);
         for (x=0; x < (long) image->columns; x++)
           *q++=(unsigned char) indexes[x];
       }
