@@ -431,7 +431,7 @@ static MagickBooleanType GetAbsoluteError(const Image *image,
       q++;
     }
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_GetAbsoluteError)
 #endif
     for (i=0; i <= (long) AllChannels; i++)
       distortion[i]+=channel_distortion[i];
@@ -558,7 +558,7 @@ static MagickBooleanType GetMeanAbsoluteError(const Image *image,
       q++;
     }
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_GetMeanAbsoluteError)
 #endif
     for (i=0; i <= (long) AllChannels; i++)
       distortion[i]+=channel_distortion[i];
@@ -794,7 +794,7 @@ static MagickBooleanType GetMeanSquaredError(const Image *image,
       q++;
     }
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_GetMeanSquaredError)
 #endif
     for (i=0; i <= (long) AllChannels; i++)
       distortion[i]+=channel_distortion[i];
@@ -907,7 +907,7 @@ static MagickBooleanType GetPeakAbsoluteError(const Image *image,
       q++;
     }
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical
+  #pragma omp critical (MagickCore_GetPeakAbsoluteError)
 #endif
     for (i=0; i <= (long) AllChannels; i++)
       if (channel_distortion[i] > distortion[i])
