@@ -10,14 +10,14 @@
 %                  M   M   OOO   DDDD    UUU   LLLLL  EEEEE                   %
 %                                                                             %
 %                                                                             %
-%                         ImageMagick Module Methods                          %
+%                          MagickCore Module Methods                          %
 %                                                                             %
 %                              Software Design                                %
 %                              Bob Friesenhahn                                %
 %                                March 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -162,12 +162,12 @@ MagickExport ModuleInfo *AcquireModuleInfo(const char *path,const char *tag)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DestroyMagickList() unregisters any previously loaded modules and exits
+%  DestroyModuleList() unregisters any previously loaded modules and exits
 %  the module loaded environment.
 %
-%  The format of the DestroyMagickList module is:
+%  The format of the DestroyModuleList module is:
 %
-%      void DestroyMagickList(void)
+%      void DestroyModuleList(void)
 %
 */
 MagickExport void DestroyModuleList(void)
@@ -212,7 +212,7 @@ MagickExport void DestroyModuleList(void)
 %    o tag: a character string that represents the image format we are
 %      looking for.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport const ModuleInfo *GetModuleInfo(const char *tag,
@@ -227,12 +227,18 @@ MagickExport const ModuleInfo *GetModuleInfo(const char *tag,
     return((const ModuleInfo *) NULL);
   if ((tag == (const char *) NULL) || (LocaleCompare(tag,"*") == 0))
     {
+      const ModuleInfo
+        *p;
+
 #if defined(MAGICKCORE_MODULES_SUPPORT)
       if (LocaleCompare(tag,"*") == 0)
         (void) OpenModules(exception);
 #endif
+      AcquireSemaphoreInfo(&module_semaphore);
       ResetSplayTreeIterator(module_list);
-      return((const ModuleInfo *) GetNextValueInSplayTree(module_list));
+      p=(const ModuleInfo *) GetNextValueInSplayTree(module_list);
+      RelinquishSemaphoreInfo(module_semaphore);
+      return(p);
     }
   return((const ModuleInfo *) GetValueFromSplayTree(module_list,tag));
 }
@@ -261,7 +267,7 @@ MagickExport const ModuleInfo *GetModuleInfo(const char *tag,
 %
 %    o number_modules:  This integer returns the number of modules in the list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -358,7 +364,7 @@ MagickExport const ModuleInfo **GetModuleInfoList(const char *pattern,
 %    o number_modules:  This integer returns the number of modules in the
 %      list.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -499,7 +505,7 @@ MagickExport char **GetModuleList(const char *pattern,
 %
 %    o path: the path associated with the filename.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType GetMagickModulePath(const char *filename,
@@ -633,7 +639,7 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
         }
       (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",(char *) key_value,
         DirectorySeparator,filename);
-      key_value=(unsigned char *) RelinquishMagickMemory(key_value); 
+      key_value=(unsigned char *) RelinquishMagickMemory(key_value);
       if (IsPathAccessible(path) == MagickFalse)
         {
           ThrowFileException(exception,ConfigureWarning,
@@ -730,12 +736,15 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
     /*
       Search module path.
     */
-    if (NTGetModulePath("CORE_RL_magick_.dll",path) != MagickFalse)
-      if (IsPathAccessible(path) != MagickFalse)
-        return(MagickTrue);
-    if (NTGetModulePath("Magick.dll",path) != MagickFalse)
-      if (IsPathAccessible(path) != MagickFalse)
-        return(MagickTrue);
+    if ((NTGetModulePath("CORE_RL_magick_.dll",path) != MagickFalse) ||
+        (NTGetModulePath("CORE_DB_magick_.dll",path) != MagickFalse) ||
+        (NTGetModulePath("Magick.dll",path) != MagickFalse))
+      {
+        (void) ConcatenateMagickString(path,DirectorySeparator,MaxTextExtent);
+        (void) ConcatenateMagickString(path,filename,MaxTextExtent);
+        if (IsPathAccessible(path) != MagickFalse)
+          return(MagickTrue);
+      }
   }
 #endif
   {
@@ -789,7 +798,7 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
 %
 %  A description of each parameter follows.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 
@@ -1000,7 +1009,7 @@ MagickExport MagickBooleanType InvokeDynamicImageFilter(const char *tag,
 %
 %    o file:  An pointer to a FILE.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType ListModuleInfo(FILE *file,
@@ -1066,7 +1075,7 @@ MagickExport MagickBooleanType ListModuleInfo(FILE *file,
 %
 %    o module: a character string that indicates the module to load.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType OpenModule(const char *module,
@@ -1168,9 +1177,8 @@ MagickExport MagickBooleanType OpenModule(const char *module,
   if (signature != MagickImageCoderSignature)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),ModuleError,
-        "CoderSignatureMismatch","`%s': %8lx != %8lx",module_name,signature,
-        MagickImageCoderSignature);
-      module_info->unregister_module();
+        "ImageCoderSignatureMismatch","`%s': %8lx != %8lx",module_name,
+        signature,MagickImageCoderSignature);
       return(MagickFalse);
     }
   return(MagickTrue);
@@ -1195,7 +1203,7 @@ MagickExport MagickBooleanType OpenModule(const char *module,
 %
 %  A description of each parameter follows:
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 MagickExport MagickBooleanType OpenModules(ExceptionInfo *exception)
@@ -1253,7 +1261,7 @@ MagickExport MagickBooleanType OpenModules(ExceptionInfo *exception)
 %
 %    o module_info: a pointer to the ModuleInfo structure to register.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static const ModuleInfo *RegisterModule(const ModuleInfo *module_info,
@@ -1437,7 +1445,7 @@ static void TagToModuleName(const char *tag,const char *format,char *module)
 %
 %    o module_info: the module info.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 static MagickBooleanType UnregisterModule(const ModuleInfo *module_info,
