@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -25,11 +25,15 @@ extern "C" {
 static inline MagickBooleanType SetImageProgress(const Image *image,
   const char *tag,const MagickOffsetType offset,const MagickSizeType extent)
 {
+  char
+    message[MaxTextExtent];
+
   if (image->progress_monitor == (MagickProgressMonitor) NULL)
     return(MagickTrue);
   if (QuantumTick(offset,extent) == MagickFalse)
     return(MagickTrue);
-  return(image->progress_monitor(tag,offset,extent,image->client_data));
+  (void) FormatMagickString(message,MaxTextExtent,"%s/%s",tag,image->filename);
+  return(image->progress_monitor(message,offset,extent,image->client_data));
 }
 
 #if defined(__cplusplus) || defined(c_plusplus)
