@@ -10,14 +10,14 @@
 %                                 N   N    T                                  %
 %                                                                             %
 %                                                                             %
-%                  Windows NT Utility Methods for ImageMagick                 %
+%                   Windows NT Utility Methods for MagickCore                 %
 %                                                                             %
 %                               Software Design                               %
 %                                 John Cristy                                 %
 %                                December 1996                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,7 +54,7 @@
 #endif
 #include "magick/nt-base.h"
 #if defined(MAGICKCORE_CIPHER_SUPPORT)
-#include <NTSecAPI.h>
+#include <ntsecapi.h>
 #include <wincrypt.h>
 #endif
 
@@ -492,7 +492,7 @@ MagickExport int NTExitLibrary(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  NTGatherRandomData() gathers random datand returns it.
+%  NTGatherRandomData() gathers random data and returns it.
 %
 %  The format of the GatherRandomData method is:
 %
@@ -2035,7 +2035,6 @@ MagickExport long NTSystemConfiguration(int name)
   }
   return(-1);
 }
-
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
