@@ -326,7 +326,7 @@ static MagickBooleanType GetPathTemplate(char *path)
     directory=GetEnvironmentValue("MAGICK_TMPDIR");
   if (directory == (char *) NULL)
     directory=GetEnvironmentValue("TMPDIR");
-#if defined(__WINDOWS__)
+#if defined(__WINDOWS__) || defined(__OS2__)
   if (directory == (char *) NULL)
     directory=GetEnvironmentValue("TMP");
   if (directory == (char *) NULL)
@@ -411,6 +411,9 @@ MagickExport int AcquireUniqueFileResource(char *path)
     (void) GetPathTemplate(path);
 #if defined(MAGICKCORE_HAVE_MKSTEMP)
     file=mkstemp(path);
+#if defined(__OS2__)
+    setmode(file,O_BINARY);
+#endif
     if (file != -1)
       break;
 #endif
