@@ -110,7 +110,7 @@ MagickExport Image *AffineTransformImage(const Image *image,
     distort[6];
 
   Image
-    *affine_image;
+    *deskew_image;
 
   /*
     Affine transform image.
@@ -127,9 +127,9 @@ MagickExport Image *AffineTransformImage(const Image *image,
   distort[3]=affine_matrix->sy;
   distort[4]=affine_matrix->tx;
   distort[5]=affine_matrix->ty;
-  affine_image=DistortImage(image,AffineProjectionDistortion,6,distort,
+  deskew_image=DistortImage(image,AffineProjectionDistortion,6,distort,
     MagickTrue,exception);
-  return(affine_image);
+  return(deskew_image);
 }
 
 /*
@@ -874,6 +874,9 @@ static void GetImageBackgroundColor(Image *image,const long offset,
 MagickExport Image *DeskewImage(const Image *image,const double threshold,
   ExceptionInfo *exception)
 {
+  AffineMatrix
+    affine_matrix;
+
   const char
     *artifact;
 
@@ -883,8 +886,8 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
   Image
     *clone_image,
     *crop_image,
-    *median_image,
-    *rotate_image;
+    *deskew_image,
+    *median_image;
 
   long
     skew;
@@ -931,28 +934,39 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
   /*
     Deskew image.
   */
+  clone_image=CloneImage(image,0,0,MagickTrue,exception);
+  if (clone_image == (Image *) NULL)
+    return((Image *) NULL);
+  (void) SetImageVirtualPixelMethod(clone_image,BackgroundVirtualPixelMethod);
   degrees=RadiansToDegrees(-atan((double) skew/width/8));
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TransformEvent,GetMagickModule(),"  Deskew angle: %g",
       degrees);
+  affine_matrix.sx=cos(DegreesToRadians(fmod((double) degrees,360.0)));
+  affine_matrix.rx=sin(DegreesToRadians(fmod((double) degrees,360.0)));
+  affine_matrix.ry=(-sin(DegreesToRadians(fmod((double) degrees,360.0))));
+  affine_matrix.sy=cos(DegreesToRadians(fmod((double) degrees,360.0)));
+  affine_matrix.tx=0.0;
+  affine_matrix.ty=0.0;
   artifact=GetImageArtifact(image,"deskew:auto-crop");
   if (artifact == (const char *) NULL)
-    return(RotateImage(image,degrees,exception));
+    {
+      deskew_image=AffineTransformImage(clone_image,&affine_matrix,exception);
+      clone_image=DestroyImage(clone_image);
+      return(deskew_image);
+    }
   /*
     Auto-crop image.
   */
-  clone_image=CloneImage(image,0,0,MagickTrue,exception);
-  if (clone_image == (Image *) NULL)
-    return((Image *) NULL);
   GetImageBackgroundColor(clone_image,atol(artifact),exception);
-  rotate_image=RotateImage(clone_image,degrees,exception);
+  deskew_image=AffineTransformImage(clone_image,&affine_matrix,exception);
   clone_image=DestroyImage(clone_image);
-  if (rotate_image == (Image *) NULL)
+  if (deskew_image == (Image *) NULL)
     return((Image *) NULL);
-  median_image=MedianFilterImage(rotate_image,0.0,exception);
+  median_image=MedianFilterImage(deskew_image,0.0,exception);
   if (median_image == (Image *) NULL)
     {
-      rotate_image=DestroyImage(rotate_image);
+      deskew_image=DestroyImage(deskew_image);
       return((Image *) NULL);
     }
   geometry=GetImageBoundingBox(median_image,exception);
@@ -960,8 +974,8 @@ MagickExport Image *DeskewImage(const Image *image,const double threshold,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TransformEvent,GetMagickModule(),"  Deskew geometry: "
       "%lux%lu%+ld%+ld",geometry.width,geometry.height,geometry.x,geometry.y);
-  crop_image=CropImage(rotate_image,&geometry,exception);
-  rotate_image=DestroyImage(rotate_image);
+  crop_image=CropImage(deskew_image,&geometry,exception);
+  deskew_image=DestroyImage(deskew_image);
   return(crop_image);
 }
 
@@ -1076,13 +1090,12 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
             continue;
           }
         indexes=GetCacheViewVirtualIndexQueue(image_view);
+        rotate_indexes=GetCacheViewAuthenticIndexQueue(rotate_view);
         (void) CopyMagickMemory(q,p,image->columns*sizeof(*p));
-        if (indexes != (IndexPacket *) NULL)
-          {
-            rotate_indexes=GetCacheViewAuthenticIndexQueue(rotate_view);
-            (void) CopyMagickMemory(rotate_indexes,indexes,image->columns*
-              sizeof(*indexes));
-          }
+        if ((indexes != (IndexPacket *) NULL) &&
+            (rotate_indexes != (IndexPacket *) NULL))
+          (void) CopyMagickMemory(rotate_indexes,indexes,image->columns*
+            sizeof(*indexes));
         sync=SyncCacheViewAuthenticPixels(rotate_view,exception);
         if (sync == MagickFalse)
           status=MagickFalse;
@@ -1168,7 +1181,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
             register long
               x;
 
-            q=QueueCacheViewAuthenticPixels(rotate_view,(long) 
+            q=QueueCacheViewAuthenticPixels(rotate_view,(long)
               rotate_image->columns-(tile_y+tile_height),y+tile_x,tile_height,
               1,exception);
             if (q == (PixelPacket *) NULL)
@@ -1261,15 +1274,14 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
             continue;
           }
         indexes=GetCacheViewVirtualIndexQueue(image_view);
+        rotate_indexes=GetCacheViewAuthenticIndexQueue(rotate_view);
         q+=image->columns;
         for (x=0; x < (long) image->columns; x++)
           *--q=(*p++);
-        if (indexes != (IndexPacket *) NULL)
-          {
-            rotate_indexes=GetCacheViewAuthenticIndexQueue(rotate_view);
-            for (x=0; x < (long) image->columns; x++)
-              rotate_indexes[image->columns-x-1]=indexes[x];
-          }
+        if ((indexes != (IndexPacket *) NULL) &&
+            (rotate_indexes != (IndexPacket *) NULL))
+          for (x=0; x < (long) image->columns; x++)
+            rotate_indexes[image->columns-x-1]=indexes[x];
         sync=SyncCacheViewAuthenticPixels(rotate_view,exception);
         if (sync == MagickFalse)
           status=MagickFalse;
@@ -1544,7 +1556,7 @@ static MagickBooleanType XShearImage(Image *image,const MagickRealType degrees,
   exception=(&image->exception);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress, status)
+  #pragma omp parallel for schedule(dynamic,8) shared(progress, status)
 #endif
   for (y=0; y < (long) height; y++)
   {
@@ -1764,7 +1776,7 @@ static MagickBooleanType YShearImage(Image *image,const MagickRealType degrees,
   exception=(&image->exception);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress, status)
+  #pragma omp parallel for schedule(dynamic,8) shared(progress, status)
 #endif
   for (x=0; x < (long) width; x++)
   {
