@@ -192,6 +192,7 @@ MagickExport void RegisterStaticModules(void)
   (void) RegisterGRAYImage();
   (void) RegisterGRADIENTImage();
   (void) RegisterHISTOGRAMImage();
+  (void) RegisterHRZImage();
   (void) RegisterHTMLImage();
   (void) RegisterICONImage();
   (void) RegisterINFOImage();
@@ -356,6 +357,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterGRAYImage();
   UnregisterGRADIENTImage();
   UnregisterHISTOGRAMImage();
+  UnregisterHRZImage();
   UnregisterHTMLImage();
   UnregisterICONImage();
   UnregisterINFOImage();
