@@ -1218,7 +1218,11 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
   if (threshold_map == (const char *) NULL)
     return(MagickTrue);
   {
-    char token[MaxTextExtent], *p;
+    char
+      token[MaxTextExtent];
+
+    register const char
+      *p;
 
     p=(char *)threshold_map;
     while (((isspace((int) ((unsigned char) *p)) != 0) || (*p == ',')) &&
@@ -1247,7 +1251,7 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
   { /* parse directly as a comma seperated list of integers */
     char *p;
 
-    p = strchr(threshold_map,',');
+    p = strchr((char *) threshold_map,',');
     if ( p != (char *)NULL && isdigit((int) ((unsigned char) *(++p))) )
       levels.index = (unsigned long) strtol(p, &p, 10);
     else
@@ -1262,7 +1266,7 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
 
     /* if more than a single number, each channel has a separate value */
     if ( p != (char *) NULL && *p == ',' ) {
-      p=strchr(threshold_map,',');
+      p=strchr((char *) threshold_map,',');
       p++;
       if ((channel & RedChannel) != 0)
         levels.red = (unsigned long) strtol(p, &p, 10),   (void)(*p == ',' && p++);
