@@ -249,6 +249,9 @@ extern WandExport MagickBooleanType
   MagickScaleImage(MagickWand *,const unsigned long,const unsigned long),
   MagickSegmentImage(MagickWand *,const ColorspaceType,const MagickBooleanType,
     const double,const double),
+  MagickSelectiveBlurImage(MagickWand *,const double,const double,const double),
+  MagickSelectiveBlurImageChannel(MagickWand *,const ChannelType,const double,
+    const double,const double),
   MagickSeparateImageChannel(MagickWand *,const ChannelType),
   MagickSepiaToneImage(MagickWand *,const double),
   MagickSetImage(MagickWand *,const MagickWand *),
