@@ -2,7 +2,11 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
-%                               A N A L I Z E                                 %
+%                AAA   N   N   AAA   L      Y   Y  ZZZZZ  EEEEE               %
+%               A   A  NN  N  A   A  L       Y Y      ZZ  E                   %
+%               AAAAA  N N N  AAAAA  L        Y     ZZZ   EEE                 %
+%               A   A  N  NN  A   A  L        Y    ZZ     E                   %
+%               A   A  N   N  A   A  LLLLL    Y    ZZZZZ  EEEEE               %
 %                                                                             %
 %               Methods to Compute a Information about an Image               %
 %                                                                             %
@@ -12,7 +16,7 @@
 %                              December 1998                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,8 +56,9 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  analyzeImage() computes the brightness and saturation mean and standard
-%  deviation and stores these values as attributes of the image.
+%  analyzeImage() computes the brightness and saturation mean,  standard
+%  deviation, kurtosis and skewness and stores these values as attributes 
+%  of the image.
 %
 %  The format of the analyzeImage method is:
 %
@@ -62,7 +67,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The address of a structure of type Image.
+%    o image: the address of a structure of type Image.
 %
 %    o argc: Specifies a pointer to an integer describing the number of
 %      elements in the argument vector.
@@ -70,7 +75,7 @@
 %    o argv: Specifies a pointer to a text array containing the command line
 %      arguments.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception: return any errors or warnings in this structure.
 %
 */
 ModuleExport unsigned long analyzeImage(Image **images,const int argc,
@@ -83,12 +88,20 @@ ModuleExport unsigned long analyzeImage(Image **images,const int argc,
     area,
     brightness_mean,
     brightness_standard_deviation,
+    brightness_kurtosis,
+    brightness_skewness,
     brightness_sum_x,
     brightness_sum_x2,
+    brightness_sum_x3,
+    brightness_sum_x4,
     saturation_mean,
     saturation_standard_deviation,
+    saturation_kurtosis,
+    saturation_skewness,
     saturation_sum_x,
-    saturation_sum_x2;
+    saturation_sum_x2,
+    saturation_sum_x3,
+    saturation_sum_x4;
 
   double
     brightness,
@@ -117,16 +130,24 @@ ModuleExport unsigned long analyzeImage(Image **images,const int argc,
   {
     brightness_sum_x=0.0;
     brightness_sum_x2=0.0;
+    brightness_sum_x3=0.0;
+    brightness_sum_x4=0.0;
     brightness_mean=0.0;
     brightness_standard_deviation=0.0;
+    brightness_kurtosis=0.0;
+    brightness_skewness=0.0;
     saturation_sum_x=0.0;
     saturation_sum_x2=0.0;
+    saturation_sum_x3=0.0;
+    saturation_sum_x4=0.0;
     saturation_mean=0.0;
     saturation_standard_deviation=0.0;
+    saturation_kurtosis=0.0;
+    saturation_skewness=0.0;
     area=0.0;
     for (y=0; y < (long) image->rows; y++)
     {
-      p=AcquireImagePixels(image,0,y,image->columns,1,exception);
+      p=GetVirtualPixels(image,0,y,image->columns,1,exception);
       if (p == (const PixelPacket *) NULL)
         break;
       for (x=0; x < (long) image->columns; x++)
@@ -135,9 +156,13 @@ ModuleExport unsigned long analyzeImage(Image **images,const int argc,
         brightness*=QuantumRange;
         brightness_sum_x+=brightness;
         brightness_sum_x2+=brightness*brightness;
+        brightness_sum_x3+=brightness*brightness*brightness;
+        brightness_sum_x4+=brightness*brightness*brightness*brightness;
         saturation*=QuantumRange;
         saturation_sum_x+=saturation;
         saturation_sum_x2+=saturation*saturation;
+        saturation_sum_x3+=saturation*saturation*saturation;
+        saturation_sum_x4+=saturation*saturation*saturation*saturation;
         area++;
         p++;
       }
@@ -152,6 +177,22 @@ ModuleExport unsigned long analyzeImage(Image **images,const int argc,
     (void) FormatMagickString(text,MaxTextExtent,"%g",
       brightness_standard_deviation);
     (void) SetImageProperty(image,"filter:brightness:standard-deviation",text);
+    if (brightness_standard_deviation != 0)
+      brightness_kurtosis=(brightness_sum_x4/area-4.0*brightness_mean*
+        brightness_sum_x3/area+6.0*brightness_mean*brightness_mean*
+        brightness_sum_x2/area-3.0*brightness_mean*brightness_mean*
+        brightness_mean*brightness_mean)/(brightness_standard_deviation*
+        brightness_standard_deviation*brightness_standard_deviation*
+        brightness_standard_deviation)-3.0;
+    (void) FormatMagickString(text,MaxTextExtent,"%g",brightness_kurtosis);
+    (void) SetImageProperty(image,"filter:brightness:kurtosis",text);
+    if (brightness_standard_deviation != 0)
+      brightness_skewness=(brightness_sum_x3/area-3.0*brightness_mean*
+        brightness_sum_x2/area+2.0*brightness_mean*brightness_mean*
+        brightness_mean)/(brightness_standard_deviation*
+        brightness_standard_deviation*brightness_standard_deviation);
+    (void) FormatMagickString(text,MaxTextExtent,"%g",brightness_skewness);
+    (void) SetImageProperty(image,"filter:brightness:skewness",text);
     saturation_mean=saturation_sum_x/area;
     (void) FormatMagickString(text,MaxTextExtent,"%g",saturation_mean);
     (void) SetImageProperty(image,"filter:saturation:mean",text);
@@ -160,6 +201,22 @@ ModuleExport unsigned long analyzeImage(Image **images,const int argc,
     (void) FormatMagickString(text,MaxTextExtent,"%g",
       saturation_standard_deviation);
     (void) SetImageProperty(image,"filter:saturation:standard-deviation",text);
+    if (saturation_standard_deviation != 0)
+      saturation_kurtosis=(saturation_sum_x4/area-4.0*saturation_mean*
+        saturation_sum_x3/area+6.0*saturation_mean*saturation_mean*
+        saturation_sum_x2/area-3.0*saturation_mean*saturation_mean*
+        saturation_mean*saturation_mean)/(saturation_standard_deviation*
+        saturation_standard_deviation*saturation_standard_deviation*
+        saturation_standard_deviation)-3.0;
+    (void) FormatMagickString(text,MaxTextExtent,"%g",saturation_kurtosis);
+    (void) SetImageProperty(image,"filter:saturation:kurtosis",text);
+    if (saturation_standard_deviation != 0)
+      saturation_skewness=(saturation_sum_x3/area-3.0*saturation_mean*
+        saturation_sum_x2/area+2.0*saturation_mean*saturation_mean*
+        saturation_mean)/(saturation_standard_deviation*
+        saturation_standard_deviation*saturation_standard_deviation);
+    (void) FormatMagickString(text,MaxTextExtent,"%g",saturation_skewness);
+    (void) SetImageProperty(image,"filter:saturation:skewness",text);
   }
   return(MagickImageFilterSignature);
 }
